# Generated by Django 3.2.7 on 2022-07-14 05:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0016_powervend'),
    ]

    operations = [
        migrations.AddField(
            model_name='workorder',
            name='agentAssignedAt',
            field=models.DateTimeField(blank=True, db_column='agentAssignedAt', null=True),
        ),
        migrations.AlterField(
            model_name='wallethistory',
            name='type',
            field=models.CharField(blank=True, choices=[('earnings', 'earnings'), ('deposit', 'deposit'), ('withdrawal', 'withdrawal'), ('payment', 'payment')], max_length=30, null=True),
        ),
    ]
