# Generated by Django 3.2.7 on 2022-06-24 19:26

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0008_auto_20220623_0423'),
    ]

    operations = [
        migrations.RenameField(
            model_name='disco',
            old_name='name',
            new_name='longName',
        ),
        migrations.RemoveField(
            model_name='disco',
            name='description',
        ),
        migrations.AddField(
            model_name='disco',
            name='shortName',
            field=models.CharField(default='', max_length=10),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='user',
            name='employerAddress',
            field=models.TextField(blank=True, db_column='employerAddress', null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='employerName',
            field=models.CharField(blank=True, db_column='employerName', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='idNumber',
            field=models.CharField(blank=True, db_column='idNumber', max_length=30, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='idType',
            field=models.CharField(blank=True, db_column='idType', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='landlordAddress',
            field=models.TextField(blank=True, db_column='landlordAddress', null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='landlordName',
            field=models.CharField(blank=True, db_column='landlordName', max_length=255, null=True),
        ),
        migrations.CreateModel(
            name='BusinessUnit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('deletedViaCascade', models.BooleanField(default=False, editable=False)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('deleted', models.BooleanField(default=False)),
                ('deletedById', models.UUIDField(blank=True, null=True)),
                ('deletedAt', models.DateTimeField(blank=True, db_column='deletedAt', null=True)),
                ('createdAt', models.DateTimeField(auto_now_add=True, db_column='createdAt')),
                ('updatedAt', models.DateTimeField(auto_now=True, db_column='updatedAt')),
                ('name', models.CharField(max_length=255)),
                ('location', models.TextField(blank=True, null=True)),
                ('status', models.CharField(blank=True, max_length=30, null=True)),
                ('createdBy', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
                ('disco', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='business_units', to='app.disco')),
            ],
            options={
                'db_table': 'BusinessUnits',
            },
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='businessUnit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.businessunit'),
        ),
    ]
