# Generated by Django 3.2.7 on 2022-07-03 19:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0013_auto_20220628_1815'),
    ]

    operations = [
        migrations.AddField(
            model_name='meterrequest',
            name='orderId',
            field=models.CharField(db_column='orderId', default='0000000000', max_length=30),
            preserve_default=False,
        ),
    ]
