from mojec_core.app.managers.firebase_manager import FirebaseManager
from mojec_core.app.managers.push_notification_manager import \
    PushNotificationManager

firebase_manager = FirebaseManager()
push_notification_manager = PushNotificationManager()

