# Generated by Django 3.2.7 on 2022-07-12 22:49

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0015_meterrequest_status'),
    ]

    operations = [
        migrations.CreateModel(
            name='PowerVend',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('deletedViaCascade', models.BooleanField(default=False, editable=False)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('deleted', models.BooleanField(default=False)),
                ('deletedById', models.UUIDField(blank=True, null=True)),
                ('deletedAt', models.DateTimeField(blank=True, db_column='deletedAt', null=True)),
                ('createdAt', models.DateTimeField(auto_now_add=True, db_column='createdAt')),
                ('updatedAt', models.DateTimeField(auto_now=True, db_column='updatedAt')),
                ('meter_number', models.CharField(max_length=250)),
                ('red_code', models.CharField(max_length=250)),
                ('amount', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('status', models.CharField(blank=True, default='new', max_length=30, null=True)),
                ('token', models.CharField(max_length=250)),
                ('action', models.CharField(max_length=250)),
                ('createdBy', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'PowerVend',
            },
        ),
    ]
